@@ -1,7 +1,7 @@
 """Define various miscellaneous utility functions."""
-from typing import Any
+from typing import Any, Dict
 
 
-def get_nearest_by_numeric_key(data: dict, key: int) -> Any:
+def get_nearest_by_numeric_key(data: Dict[int, Any], key: int) -> Any:
     """Return the dict element whose numeric key is closest to a target."""
     return data.get(key, data[min(data.keys(), key=lambda k: abs(k - key))])
